Crate looking_glass_protobuf

Crate looking_glass_protobuf 

Structs

DescriptorDatabase
A database of message and enum descriptors.
DynamicMessage
A looking_glass representation of a ProtocolBuffer message.
EnumDescriptor
Field
FieldDescriptor
MessageDescriptor
A parsed message descriptor
MessageView
A parsed view into the bytes of a Protocol Buffer message
RawMessageView
A view into the bytes of a Protocol Buffer message
StrTranche

Enums

Error
FieldType
RawField
RepeatedValueView
ValueView
A view into a Protocol Buffer value

Traits

Tranche

Functions

add_bytes_to_repeated_view
bytes_to_value_view