Structs
- Descriptor
Database - A database of message and enum descriptors.
- Dynamic
Message - A looking_glass representation of a ProtocolBuffer message.
- Enum
Descriptor - Field
- Field
Descriptor - Message
Descriptor - A parsed message descriptor
- Message
View - A parsed view into the bytes of a Protocol Buffer message
- RawMessage
View - A view into the bytes of a Protocol Buffer message
- StrTranche
Enums
- Error
- Field
Type - RawField
- Repeated
Value View - Value
View - A view into a Protocol Buffer value